BioSPPy is written and maintained by the [ScientISST](https://github.com/scientisst) team.

Maintainers
-----------

- Rafael Silva [@rafaelscsilva](https://github.com/rafaelscsilva)
- Sofia Monteiro [@sofia3ms](https://github.com/sofia3ms)
- Ana Sofia Carmo [@anascacais](https://github.com/anascacais)

Main Contributors
-----------------

- Rafael Silva [@rafaelscsilva](https://github.com/rafaelscsilva)
- Sofia Monteiro [@sofia3ms](https://github.com/sofia3ms)
- Patrícia Bota [@PatriciaBota](https://github.com/PatriciaBota)
- Afonso Ferreira [@afonsof3rreira](https://github.com/afonsof3rreira)
- Mariana Abreu [@MarianaAbreu](https://github.com/MarianaAbreu)

Scientific Supervision
----------------------

- Ana Fred (1)
- Hugo Silva [@hugoslv](https://github.com/hugoslv) (1)

(1) Instituto de Telecomunicações, Instituto Superior Técnico, Universidade de
Lisboa, Portugal

[Contact](mailto:hugo.silva@lx.it.pt?subject=BioSPPy%20Question)